@@ -6,12 +6,12 @@
     <message>
         <location filename="../src/mainwindow.ui" line="14"/>
         <source>OpenSSH Authentication Passphrase request</source>
-        <translation>Anmodning om adgangsfrase til OpenSSH-godkendelse</translation>
+        <translation>Anmodning om adgangskode til OpenSSH-godkendelse</translation>
     </message>
     <message>
         <location filename="../src/mainwindow.ui" line="20"/>
         <source>Enter your SSH passphrase for request:</source>
-        <translation>Indtast din SSH-adgangsfrase for anmodning:</translation>
+        <translation>Indtast din SSH-adgangskode for anmodning:</translation>
     </message>
 </context>
 <context>
